@@ -28,7 +28,10 @@ void DownloadManager::setDownloadQuality(const QString &quality) {
 }
 
 void DownloadManager::getVideoUrl(const QString &playerUrl) {
-    downloadReply = nam->get(QNetworkRequest(QUrl(playerUrl)));
+    QString url = playerUrl;
+    QString videoId = url.split("v=").last().split("&").first();
+    QString pageUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&ps=default&eurl=&gl=US&hl=en";
+    downloadReply = nam->get(QNetworkRequest(QUrl(pageUrl)));
     connect(downloadReply, SIGNAL(finished()), this, SLOT(parseVideoPage()));
 }
 
@@ -38,17 +41,20 @@ void DownloadManager::parseVideoPage() {
         return;
     }
     QMap<int, QByteArray> formats;
-    QByteArray response = downloadReply->readAll();
-    response = response.simplified().replace(QByteArray(" "), QByteArray(""));
-    int pos = response.indexOf("\",\"fmt_url_map\":\"") + 17;
-    int pos2 = response.indexOf('\"', pos);
+    QByteArray response = QByteArray::fromPercentEncoding(downloadReply->readAll());
+    int pos = response.indexOf("fmt_url_map=") + 12;
+    int pos2 = response.indexOf("&allow_ratings", pos);
+    int pos3 = response.indexOf("&leanback", pos);
+    if ((pos3 > 0) && (pos3 < pos2)) {
+        pos2 = pos3;
+    }
     response = response.mid(pos, pos2 - pos);
     QList<QByteArray> parts = response.split('|');
     int key = parts.first().toInt();
     for (int i = 1; i < parts.length(); i++) {
         QByteArray part = parts[i];
         QList<QByteArray> keyAndValue = part.split(',');
-        QByteArray url = keyAndValue.first().replace(QByteArray("\\/"), QByteArray("/")).replace(QByteArray("\\u0026"), QByteArray("&"));
+        QByteArray url = keyAndValue.first();
         formats[key] = url;
         key = keyAndValue.last().toInt();
     }
