@@ -64,9 +64,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.6 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.7</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.7 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.7 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.0</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.0 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -205,7 +209,7 @@
 <context>
     <name>BusyDialog</name>
     <message>
-        <location filename="../BusyDialog.qml" line="50"/>
+        <location filename="../BusyDialog.qml" line="47"/>
         <source>Loading...</source>
         <translation>Lade...</translation>
     </message>
@@ -386,6 +390,45 @@
         <translation>Archiv</translation>
     </message>
 </context>
+<context>
+    <name>InboxDelegate</name>
+    <message>
+        <location filename="../InboxDelegate.qml" line="44"/>
+        <location filename="../InboxDelegate.qml" line="46"/>
+        <source>From </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="45"/>
+        <location filename="../InboxDelegate.qml" line="47"/>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source> on </source>
+        <translation type="unfinished"> am </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source>By </source>
+        <translation type="unfinished">Von </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="145"/>
+        <source>Views</source>
+        <translation type="unfinished">Aufrufe</translation>
+    </message>
+</context>
+<context>
+    <name>InboxDialog</name>
+    <message>
+        <location filename="../InboxDialog.qml" line="57"/>
+        <source>Inbox</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDialog.qml" line="69"/>
+        <source>No messages found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MenuBar</name>
     <message>
@@ -413,37 +456,37 @@
         <translation type="obsolete">Video hochladen</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="81"/>
+        <location filename="../MyAccountView.qml" line="98"/>
         <source>My Uploads</source>
         <translation>Mein Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="87"/>
+        <location filename="../MyAccountView.qml" line="104"/>
         <source>Uploads</source>
         <translation>Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="105"/>
+        <location filename="../MyAccountView.qml" line="122"/>
         <source>My Favourites</source>
         <translation>Mein Favoriten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="111"/>
+        <location filename="../MyAccountView.qml" line="128"/>
         <source>Favourites</source>
         <translation>Favoriten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="135"/>
+        <location filename="../MyAccountView.qml" line="152"/>
         <source>Playlists</source>
         <translation>Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="159"/>
+        <location filename="../MyAccountView.qml" line="176"/>
         <source>Subscriptions</source>
         <translation>Abonnement</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="174"/>
+        <location filename="../MyAccountView.qml" line="191"/>
         <source>Signed in as:</source>
         <translation>Angemeldet als:</translation>
     </message>
@@ -501,12 +544,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="52"/>
+        <location filename="../NotificationArea.qml" line="55"/>
         <source>No active downloads</source>
         <translation>Keine aktiven Downloads</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="147"/>
+        <location filename="../NotificationArea.qml" line="151"/>
         <source>Downloads</source>
         <translation>Downloads</translation>
     </message>
@@ -564,12 +607,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="69"/>
+        <location filename="../PlaylistVideosView.qml" line="71"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -628,7 +671,7 @@
         <translation type="obsolete">Aufrufe</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="178"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Sortieren nach:</translation>
     </message>
@@ -1262,12 +1305,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="129"/>
+        <location filename="../UserVideosView.qml" line="131"/>
         <source>You have subscribed to &apos;</source>
         <translation>Du hast ein Abonnement bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="133"/>
+        <location filename="../UserVideosView.qml" line="135"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Abonnement gekündigt bei</translation>
     </message>
@@ -1296,27 +1339,27 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="153"/>
+        <location filename="../UserVideosView.qml" line="155"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="226"/>
+        <location filename="../UserVideosView.qml" line="228"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Unsubscribe</source>
         <translation>Abonnement kündigen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Subscribe</source>
         <translation>Abonnieren</translation>
     </message>
@@ -1329,17 +1372,17 @@
         <translation>Keine Beschreibung</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="92"/>
+        <location filename="../VideoInfoView.qml" line="93"/>
         <source>Your comment has been added</source>
         <translation>Dein Kommentar wurde hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="95"/>
+        <location filename="../VideoInfoView.qml" line="96"/>
         <source>Your rating has been added</source>
         <translation>Deine Bewertung wurde hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="102"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Video shared on facebook</source>
         <translation>Video auf Facebook freigegeben</translation>
     </message>
@@ -1360,71 +1403,71 @@
         <translation type="obsolete">Auf Facebook freigeben</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="437"/>
-        <location filename="../VideoInfoView.qml" line="461"/>
-        <location filename="../VideoInfoView.qml" line="575"/>
+        <location filename="../VideoInfoView.qml" line="439"/>
+        <location filename="../VideoInfoView.qml" line="464"/>
+        <location filename="../VideoInfoView.qml" line="578"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Nicht bei einem YouTube Konto angemeldet</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="244"/>
+        <location filename="../VideoInfoView.qml" line="245"/>
         <source>Info</source>
         <translation>Info</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="283"/>
+        <location filename="../VideoInfoView.qml" line="284"/>
         <source>Comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="322"/>
+        <location filename="../VideoInfoView.qml" line="323"/>
         <source>Related</source>
         <translation>Ähnliche</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="407"/>
-        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="408"/>
+        <location filename="../VideoInfoView.qml" line="411"/>
         <source>By </source>
         <translation>Von </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="409"/>
-        <location filename="../VideoInfoView.qml" line="412"/>
+        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="413"/>
         <source> on </source>
         <translation> am </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="478"/>
+        <location filename="../VideoInfoView.qml" line="481"/>
         <source>Views</source>
         <translation>Aufrufe</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="492"/>
+        <location filename="../VideoInfoView.qml" line="495"/>
         <source>Description</source>
         <translation>Beschreibung</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="508"/>
+        <location filename="../VideoInfoView.qml" line="511"/>
         <source>Tags</source>
         <translation>Tags</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="518"/>
+        <location filename="../VideoInfoView.qml" line="521"/>
         <source>No tags</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source>No comments</source>
         <translation>Keine Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source> comments</source>
         <translation>Kommentare</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="703"/>
+        <location filename="../VideoInfoView.qml" line="706"/>
         <source>No related videos</source>
         <translation>Keine ähnlichen Videos</translation>
     </message>
@@ -1474,12 +1517,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="86"/>
+        <location filename="../VideoListView.qml" line="82"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="108"/>
+        <location filename="../VideoListView.qml" line="104"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -1585,50 +1628,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="40"/>
+        <location filename="../../../youtube.cpp" line="43"/>
         <source>Error obtaining access token</source>
         <translation>Fehler beim Zugangscode</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="55"/>
+        <location filename="../../../youtube.cpp" line="54"/>
         <source>Authentication failed</source>
         <translation>Autorisierung schlug fehl</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="59"/>
+        <location filename="../../../youtube.cpp" line="58"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>Bei YouTube angemeldet als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="164"/>
-        <location filename="../../../youtube.cpp" line="270"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
         <translation>Fehler - Serverantwort ist:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="214"/>
-        <location filename="../../../youtube.cpp" line="222"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Upload abgebrochen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="229"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="233"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Upload fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="239"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Upload ist komplett</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="437"/>
-        <location filename="../../../youtube.cpp" line="479"/>
+        <location filename="../../../youtube.cpp" line="397"/>
+        <location filename="../../../youtube.cpp" line="439"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1842,34 +1885,28 @@
         <translation type="obsolete">Media Player</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="156"/>
         <source>My Channel</source>
-        <translation>Mein Kanal</translation>
+        <translation type="obsolete">Mein Kanal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="171"/>
         <source>Archive</source>
-        <translation>Archiv</translation>
+        <translation type="obsolete">Archiv</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Playlists</source>
-        <translation>Mein Wiedergabelisten</translation>
+        <translation type="obsolete">Mein Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>My Subscriptions</source>
-        <translation>Mein Abonnement</translation>
+        <translation type="obsolete">Mein Abonnement</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
         <source>Video Info</source>
-        <translation>Video Info</translation>
+        <translation type="obsolete">Video Info</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Video Playback</source>
-        <translation>Video abspielen</translation>
+        <translation type="obsolete">Video abspielen</translation>
     </message>
     <message>
         <source>Downloads</source>
@@ -1892,9 +1929,8 @@
         <translation type="obsolete">bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="256"/>
         <source>Search </source>
-        <translation>Suchlauf</translation>
+        <translation type="obsolete">Suchlauf</translation>
     </message>
 </context>
 <context>
