@@ -44,9 +44,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.6 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.7</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.7 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.7 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.0</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.0 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -161,7 +165,7 @@
 <context>
     <name>BusyDialog</name>
     <message>
-        <location filename="../BusyDialog.qml" line="50"/>
+        <location filename="../BusyDialog.qml" line="47"/>
         <source>Loading...</source>
         <translation>Ladataan...</translation>
     </message>
@@ -330,6 +334,45 @@
         <translation>Kirjasto</translation>
     </message>
 </context>
+<context>
+    <name>InboxDelegate</name>
+    <message>
+        <location filename="../InboxDelegate.qml" line="44"/>
+        <location filename="../InboxDelegate.qml" line="46"/>
+        <source>From </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="45"/>
+        <location filename="../InboxDelegate.qml" line="47"/>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source> on </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source>By </source>
+        <translation type="unfinished">Kirjoittaja: </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="145"/>
+        <source>Views</source>
+        <translation type="unfinished">Katseluja</translation>
+    </message>
+</context>
+<context>
+    <name>InboxDialog</name>
+    <message>
+        <location filename="../InboxDialog.qml" line="57"/>
+        <source>Inbox</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDialog.qml" line="69"/>
+        <source>No messages found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MenuBar</name>
     <message>
@@ -357,37 +400,37 @@
         <translation type="obsolete">Lataa video</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="81"/>
+        <location filename="../MyAccountView.qml" line="98"/>
         <source>My Uploads</source>
         <translation>Omat lataukset</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="87"/>
+        <location filename="../MyAccountView.qml" line="104"/>
         <source>Uploads</source>
         <translation>Lataukset</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="105"/>
+        <location filename="../MyAccountView.qml" line="122"/>
         <source>My Favourites</source>
         <translation>Omat suosikit</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="111"/>
+        <location filename="../MyAccountView.qml" line="128"/>
         <source>Favourites</source>
         <translation>Suosikit</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="135"/>
+        <location filename="../MyAccountView.qml" line="152"/>
         <source>Playlists</source>
         <translation>Soittolistat</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="159"/>
+        <location filename="../MyAccountView.qml" line="176"/>
         <source>Subscriptions</source>
         <translation>Syötteet</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="174"/>
+        <location filename="../MyAccountView.qml" line="191"/>
         <source>Signed in as:</source>
         <translation>Kirjautunut:</translation>
     </message>
@@ -441,12 +484,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="52"/>
+        <location filename="../NotificationArea.qml" line="55"/>
         <source>No active downloads</source>
         <translation>Ei aktiivisia latauksia</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="147"/>
+        <location filename="../NotificationArea.qml" line="151"/>
         <source>Downloads</source>
         <translation>Lataukset</translation>
     </message>
@@ -504,12 +547,12 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="69"/>
+        <location filename="../PlaylistVideosView.qml" line="71"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
@@ -568,7 +611,7 @@
         <translation type="obsolete">Katseluja</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="178"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Järjestä: </translation>
     </message>
@@ -1194,12 +1237,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="129"/>
+        <location filename="../UserVideosView.qml" line="131"/>
         <source>You have subscribed to &apos;</source>
         <translation>Olet tilannut syötteen: </translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="133"/>
+        <location filename="../UserVideosView.qml" line="135"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Olet perunut syötteen: </translation>
     </message>
@@ -1228,27 +1271,27 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="153"/>
+        <location filename="../UserVideosView.qml" line="155"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Subscribers</source>
         <translation>Tilaajat</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="226"/>
+        <location filename="../UserVideosView.qml" line="228"/>
         <source>Videos</source>
         <translation>Videot</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Unsubscribe</source>
         <translation>Peru tilaus</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Subscribe</source>
         <translation>Tilaa</translation>
     </message>
@@ -1261,17 +1304,17 @@
         <translation>Ei kuvausta</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="92"/>
+        <location filename="../VideoInfoView.qml" line="93"/>
         <source>Your comment has been added</source>
         <translation>Kommenttisi tallennettiin</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="95"/>
+        <location filename="../VideoInfoView.qml" line="96"/>
         <source>Your rating has been added</source>
         <translation>Arviosi tallennettiin</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="102"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Video shared on facebook</source>
         <translation>Video jaettu facebookkiin</translation>
     </message>
@@ -1292,71 +1335,71 @@
         <translation type="obsolete">Jaa facebookin kautta</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="437"/>
-        <location filename="../VideoInfoView.qml" line="461"/>
-        <location filename="../VideoInfoView.qml" line="575"/>
+        <location filename="../VideoInfoView.qml" line="439"/>
+        <location filename="../VideoInfoView.qml" line="464"/>
+        <location filename="../VideoInfoView.qml" line="578"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Et ole kirjautunut YouTubeen</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="244"/>
+        <location filename="../VideoInfoView.qml" line="245"/>
         <source>Info</source>
         <translation>Tietoa</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="283"/>
+        <location filename="../VideoInfoView.qml" line="284"/>
         <source>Comments</source>
         <translation>Kommentit</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="322"/>
+        <location filename="../VideoInfoView.qml" line="323"/>
         <source>Related</source>
         <translation>Liittyvät</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="407"/>
-        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="408"/>
+        <location filename="../VideoInfoView.qml" line="411"/>
         <source>By </source>
         <translation>Kirjoittaja: </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="409"/>
-        <location filename="../VideoInfoView.qml" line="412"/>
+        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="413"/>
         <source> on </source>
         <translation> milloin: </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="478"/>
+        <location filename="../VideoInfoView.qml" line="481"/>
         <source>Views</source>
         <translation>Katseluja</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="492"/>
+        <location filename="../VideoInfoView.qml" line="495"/>
         <source>Description</source>
         <translation>Kuvaus</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="508"/>
+        <location filename="../VideoInfoView.qml" line="511"/>
         <source>Tags</source>
         <translation>Tagit</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="518"/>
+        <location filename="../VideoInfoView.qml" line="521"/>
         <source>No tags</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source>No comments</source>
         <translation>Ei kommentteja</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source> comments</source>
         <translation>kommentit</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="703"/>
+        <location filename="../VideoInfoView.qml" line="706"/>
         <source>No related videos</source>
         <translation>Ei liittyviä videoita</translation>
     </message>
@@ -1406,12 +1449,12 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="86"/>
+        <location filename="../VideoListView.qml" line="82"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="108"/>
+        <location filename="../VideoListView.qml" line="104"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
@@ -1517,50 +1560,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="40"/>
+        <location filename="../../../youtube.cpp" line="43"/>
         <source>Error obtaining access token</source>
         <translation>Virhe haettaessa varmennetta</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="55"/>
+        <location filename="../../../youtube.cpp" line="54"/>
         <source>Authentication failed</source>
         <translation>Varmennus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="59"/>
+        <location filename="../../../youtube.cpp" line="58"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>Olet kirjautunut YouTubeen tilillä: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="164"/>
-        <location filename="../../../youtube.cpp" line="270"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
         <translation>Virhe - Palvelin vastasi: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="214"/>
-        <location filename="../../../youtube.cpp" line="222"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Lataus keskeytetty</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="229"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Lataus keskeytyi. Kokeilen jatkaa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="233"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Lataus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="239"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Lataus valmistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="437"/>
-        <location filename="../../../youtube.cpp" line="479"/>
+        <location filename="../../../youtube.cpp" line="397"/>
+        <location filename="../../../youtube.cpp" line="439"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Virhe: videon lataus epäonnistui</translation>
     </message>
@@ -1770,34 +1813,28 @@
         <translation type="obsolete">Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="156"/>
         <source>My Channel</source>
-        <translation>Oma kanavani</translation>
+        <translation type="obsolete">Oma kanavani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="171"/>
         <source>Archive</source>
-        <translation>Arkisto</translation>
+        <translation type="obsolete">Arkisto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Playlists</source>
-        <translation>Omat soittolistani</translation>
+        <translation type="obsolete">Omat soittolistani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>My Subscriptions</source>
-        <translation>Omat tilaukseni</translation>
+        <translation type="obsolete">Omat tilaukseni</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
         <source>Video Info</source>
-        <translation>Videon tiedot</translation>
+        <translation type="obsolete">Videon tiedot</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Video Playback</source>
-        <translation>Videon toisto</translation>
+        <translation type="obsolete">Videon toisto</translation>
     </message>
     <message>
         <source>Downloads</source>
@@ -1820,9 +1857,8 @@
         <translation type="obsolete">arvio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="256"/>
         <source>Search </source>
-        <translation>Haku</translation>
+        <translation type="obsolete">Haku</translation>
     </message>
 </context>
 <context>
