@@ -9,7 +9,7 @@
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.7</source>
+        <source>cuteTube-QML - 0.8.0</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -121,7 +121,7 @@
 <context>
     <name>BusyDialog</name>
     <message>
-        <location filename="../BusyDialog.qml" line="50"/>
+        <location filename="../BusyDialog.qml" line="47"/>
         <source>Loading...</source>
         <translation>Caricamento...</translation>
     </message>
@@ -278,6 +278,45 @@
         <translation>Archivio</translation>
     </message>
 </context>
+<context>
+    <name>InboxDelegate</name>
+    <message>
+        <location filename="../InboxDelegate.qml" line="44"/>
+        <location filename="../InboxDelegate.qml" line="46"/>
+        <source>From </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="45"/>
+        <location filename="../InboxDelegate.qml" line="47"/>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source> on </source>
+        <translation type="unfinished"> il </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source>By </source>
+        <translation type="unfinished">Da </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="145"/>
+        <source>Views</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>InboxDialog</name>
+    <message>
+        <location filename="../InboxDialog.qml" line="57"/>
+        <source>Inbox</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDialog.qml" line="69"/>
+        <source>No messages found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MenuBar</name>
     <message>
@@ -301,37 +340,37 @@
         <translation type="obsolete">Carica video</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="81"/>
+        <location filename="../MyAccountView.qml" line="98"/>
         <source>My Uploads</source>
         <translation>I Miei Video</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="87"/>
+        <location filename="../MyAccountView.qml" line="104"/>
         <source>Uploads</source>
         <translation>Caricati</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="105"/>
+        <location filename="../MyAccountView.qml" line="122"/>
         <source>My Favourites</source>
         <translation>I Miei Preferiti</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="111"/>
+        <location filename="../MyAccountView.qml" line="128"/>
         <source>Favourites</source>
         <translation>Preferiti</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="135"/>
+        <location filename="../MyAccountView.qml" line="152"/>
         <source>Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="159"/>
+        <location filename="../MyAccountView.qml" line="176"/>
         <source>Subscriptions</source>
         <translation>Iscrizioni</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="174"/>
+        <location filename="../MyAccountView.qml" line="191"/>
         <source>Signed in as:</source>
         <translation>Accesso effettuato come:</translation>
     </message>
@@ -385,12 +424,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="52"/>
+        <location filename="../NotificationArea.qml" line="55"/>
         <source>No active downloads</source>
         <translation>Nessun download attivo</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="147"/>
+        <location filename="../NotificationArea.qml" line="151"/>
         <source>Downloads</source>
         <translation></translation>
     </message>
@@ -444,12 +483,12 @@
         <translation type="obsolete">Copia negli appunti</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="69"/>
+        <location filename="../PlaylistVideosView.qml" line="71"/>
         <source>Video(s) deleted from playlist</source>
         <translation>Video cancellato(i) dalla playlist</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Nessun video trovato</translation>
     </message>
@@ -508,7 +547,7 @@
         <translation type="obsolete">Numero di visualizzazioni</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="178"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Ordina per:</translation>
     </message>
@@ -1150,12 +1189,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="129"/>
+        <location filename="../UserVideosView.qml" line="131"/>
         <source>You have subscribed to &apos;</source>
         <translation>Ti sei iscritto a &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="133"/>
+        <location filename="../UserVideosView.qml" line="135"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Ti sei cancellato da &apos;</translation>
     </message>
@@ -1180,27 +1219,27 @@
         <translation type="obsolete">Copia negli appunti</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="153"/>
+        <location filename="../UserVideosView.qml" line="155"/>
         <source>No videos found</source>
         <translation>Nessun video trovato</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Subscribers</source>
         <translation>Iscritti</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="226"/>
+        <location filename="../UserVideosView.qml" line="228"/>
         <source>Videos</source>
         <translation>Video</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Unsubscribe</source>
         <translation>Cancellati</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Subscribe</source>
         <translation>Iscriviti</translation>
     </message>
@@ -1213,17 +1252,17 @@
         <translation>Nessuna descrizione</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="92"/>
+        <location filename="../VideoInfoView.qml" line="93"/>
         <source>Your comment has been added</source>
         <translation>Il tuo commento è stato aggiunto</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="95"/>
+        <location filename="../VideoInfoView.qml" line="96"/>
         <source>Your rating has been added</source>
         <translation>Il tuo voto è stato aggiunto</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="102"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Video shared on facebook</source>
         <translation>Video condiviso su Facebook</translation>
     </message>
@@ -1244,71 +1283,71 @@
         <translation type="obsolete">Condividi via Facebook</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="437"/>
-        <location filename="../VideoInfoView.qml" line="461"/>
-        <location filename="../VideoInfoView.qml" line="575"/>
+        <location filename="../VideoInfoView.qml" line="439"/>
+        <location filename="../VideoInfoView.qml" line="464"/>
+        <location filename="../VideoInfoView.qml" line="578"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Non hai effettuato l&apos;accesso con un account YouTube</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="244"/>
+        <location filename="../VideoInfoView.qml" line="245"/>
         <source>Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="283"/>
+        <location filename="../VideoInfoView.qml" line="284"/>
         <source>Comments</source>
         <translation>Commenti</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="322"/>
+        <location filename="../VideoInfoView.qml" line="323"/>
         <source>Related</source>
         <translation>Correlati</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="407"/>
-        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="408"/>
+        <location filename="../VideoInfoView.qml" line="411"/>
         <source>By </source>
         <translation>Da </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="409"/>
-        <location filename="../VideoInfoView.qml" line="412"/>
+        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="413"/>
         <source> on </source>
         <translation> il </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="478"/>
+        <location filename="../VideoInfoView.qml" line="481"/>
         <source>Views</source>
         <translation>Visualizzazioni</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="492"/>
+        <location filename="../VideoInfoView.qml" line="495"/>
         <source>Description</source>
         <translation>Descrizione</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="508"/>
+        <location filename="../VideoInfoView.qml" line="511"/>
         <source>Tags</source>
         <translation>Tag</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="518"/>
+        <location filename="../VideoInfoView.qml" line="521"/>
         <source>No tags</source>
         <translation>Nessun Tag</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source>No comments</source>
         <translation>Nessun commento</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source> comments</source>
         <translation> commenti</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="703"/>
+        <location filename="../VideoInfoView.qml" line="706"/>
         <source>No related videos</source>
         <translation>Nessun video correlato</translation>
     </message>
@@ -1354,12 +1393,12 @@
         <translation type="obsolete">Copia negli appunti</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="86"/>
+        <location filename="../VideoListView.qml" line="82"/>
         <source>Video(s) deleted from favourites</source>
         <translation>Video cancellato(i) dai preferiti</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="108"/>
+        <location filename="../VideoListView.qml" line="104"/>
         <source>No videos found</source>
         <translation>Nessun video trovato</translation>
     </message>
@@ -1437,50 +1476,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="40"/>
+        <location filename="../../../youtube.cpp" line="43"/>
         <source>Error obtaining access token</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="55"/>
+        <location filename="../../../youtube.cpp" line="54"/>
         <source>Authentication failed</source>
         <translation>Autenticazione fallita</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="59"/>
+        <location filename="../../../youtube.cpp" line="58"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>Hai effettuato l&apos;accesso a YouTube come &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="164"/>
-        <location filename="../../../youtube.cpp" line="270"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
         <translation>Errore - Il server ha risposto: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="214"/>
-        <location filename="../../../youtube.cpp" line="222"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Caricamento interrotto</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="229"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Caricamento interrotto. Tenetativo di ripresa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="233"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Caricamento fallito</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="239"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Caricamento completato</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="437"/>
-        <location filename="../../../youtube.cpp" line="479"/>
+        <location filename="../../../youtube.cpp" line="397"/>
+        <location filename="../../../youtube.cpp" line="439"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Errore: Impossibile recuperare il video</translation>
     </message>
@@ -1682,34 +1721,28 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="156"/>
         <source>My Channel</source>
-        <translation>Il Mio Canale</translation>
+        <translation type="obsolete">Il Mio Canale</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="171"/>
         <source>Archive</source>
-        <translation>Archivio</translation>
+        <translation type="obsolete">Archivio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Playlists</source>
-        <translation>Le Mie Playlist</translation>
+        <translation type="obsolete">Le Mie Playlist</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>My Subscriptions</source>
-        <translation>Le Mie Iscrizioni</translation>
+        <translation type="obsolete">Le Mie Iscrizioni</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
         <source>Video Info</source>
-        <translation>Info Video</translation>
+        <translation type="obsolete">Info Video</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Video Playback</source>
-        <translation>Riproduzione Video</translation>
+        <translation type="obsolete">Riproduzione Video</translation>
     </message>
     <message>
         <source>date</source>
@@ -1728,9 +1761,8 @@
         <translation type="obsolete">voto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="256"/>
         <source>Search </source>
-        <translation>Cerca </translation>
+        <translation type="obsolete">Cerca </translation>
     </message>
 </context>
 <context>
