@@ -9,7 +9,7 @@
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.7</source>
+        <source>cuteTube-QML - 0.8.0</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -121,7 +121,7 @@
 <context>
     <name>BusyDialog</name>
     <message>
-        <location filename="../BusyDialog.qml" line="50"/>
+        <location filename="../BusyDialog.qml" line="47"/>
         <source>Loading...</source>
         <translation>Laden...</translation>
     </message>
@@ -290,6 +290,45 @@
         <translation>Archief</translation>
     </message>
 </context>
+<context>
+    <name>InboxDelegate</name>
+    <message>
+        <location filename="../InboxDelegate.qml" line="44"/>
+        <location filename="../InboxDelegate.qml" line="46"/>
+        <source>From </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="45"/>
+        <location filename="../InboxDelegate.qml" line="47"/>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source> on </source>
+        <translation type="unfinished"> op </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source>By </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="145"/>
+        <source>Views</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>InboxDialog</name>
+    <message>
+        <location filename="../InboxDialog.qml" line="57"/>
+        <source>Inbox</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDialog.qml" line="69"/>
+        <source>No messages found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MenuBar</name>
     <message>
@@ -309,37 +348,37 @@
 <context>
     <name>MyAccountView</name>
     <message>
-        <location filename="../MyAccountView.qml" line="81"/>
+        <location filename="../MyAccountView.qml" line="98"/>
         <source>My Uploads</source>
         <translation>Mijn Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="87"/>
+        <location filename="../MyAccountView.qml" line="104"/>
         <source>Uploads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="105"/>
+        <location filename="../MyAccountView.qml" line="122"/>
         <source>My Favourites</source>
         <translation>Mijn Favorieten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="111"/>
+        <location filename="../MyAccountView.qml" line="128"/>
         <source>Favourites</source>
         <translation>Favorieten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="135"/>
+        <location filename="../MyAccountView.qml" line="152"/>
         <source>Playlists</source>
         <translation>Afspeellijst</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="159"/>
+        <location filename="../MyAccountView.qml" line="176"/>
         <source>Subscriptions</source>
         <translation>Abonnementen</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="174"/>
+        <location filename="../MyAccountView.qml" line="191"/>
         <source>Signed in as:</source>
         <translation>Ingelogd als:</translation>
     </message>
@@ -393,12 +432,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="52"/>
+        <location filename="../NotificationArea.qml" line="55"/>
         <source>No active downloads</source>
         <translation>Geen actieve downloads</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="147"/>
+        <location filename="../NotificationArea.qml" line="151"/>
         <source>Downloads</source>
         <translation></translation>
     </message>
@@ -444,12 +483,12 @@
         <translation type="obsolete">Kopiëren naar klembord</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="69"/>
+        <location filename="../PlaylistVideosView.qml" line="71"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Geen video&apos;s gevonden</translation>
     </message>
@@ -508,7 +547,7 @@
         <translation type="obsolete">Bekenen</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="178"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Sorteren op:</translation>
     </message>
@@ -1134,12 +1173,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="129"/>
+        <location filename="../UserVideosView.qml" line="131"/>
         <source>You have subscribed to &apos;</source>
         <translation>U heeft zich aangemeld voor &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="133"/>
+        <location filename="../UserVideosView.qml" line="135"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>U heeft zich afgemeld voor &apos;</translation>
     </message>
@@ -1156,27 +1195,27 @@
         <translation type="obsolete">Kopiëren naar klembord</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="153"/>
+        <location filename="../UserVideosView.qml" line="155"/>
         <source>No videos found</source>
         <translation>Geen videos gevonden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Subscribers</source>
         <translation>Abonnees</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="226"/>
+        <location filename="../UserVideosView.qml" line="228"/>
         <source>Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Unsubscribe</source>
         <translation>Afmelden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Subscribe</source>
         <translation>Aanmelden</translation>
     </message>
@@ -1189,17 +1228,17 @@
         <translation>Geen beschrijving</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="92"/>
+        <location filename="../VideoInfoView.qml" line="93"/>
         <source>Your comment has been added</source>
         <translation>Uw commentaar is toe gevoegd</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="95"/>
+        <location filename="../VideoInfoView.qml" line="96"/>
         <source>Your rating has been added</source>
         <translation>Uw beoordeling is toe gevoegd</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="102"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Video shared on facebook</source>
         <translation>Video gedeeld op facebook</translation>
     </message>
@@ -1220,71 +1259,71 @@
         <translation type="obsolete">Delen via facebook</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="437"/>
-        <location filename="../VideoInfoView.qml" line="461"/>
-        <location filename="../VideoInfoView.qml" line="575"/>
+        <location filename="../VideoInfoView.qml" line="439"/>
+        <location filename="../VideoInfoView.qml" line="464"/>
+        <location filename="../VideoInfoView.qml" line="578"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Je bent niet ingelogd me teen YouTube account</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="244"/>
+        <location filename="../VideoInfoView.qml" line="245"/>
         <source>Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="283"/>
+        <location filename="../VideoInfoView.qml" line="284"/>
         <source>Comments</source>
         <translation>Reacties</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="322"/>
+        <location filename="../VideoInfoView.qml" line="323"/>
         <source>Related</source>
         <translation>Gerelateerde</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="407"/>
-        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="408"/>
+        <location filename="../VideoInfoView.qml" line="411"/>
         <source>By </source>
         <translation>Door</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="409"/>
-        <location filename="../VideoInfoView.qml" line="412"/>
+        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="413"/>
         <source> on </source>
         <translation> op </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="478"/>
+        <location filename="../VideoInfoView.qml" line="481"/>
         <source>Views</source>
         <translation>Bekeken</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="492"/>
+        <location filename="../VideoInfoView.qml" line="495"/>
         <source>Description</source>
         <translation>Beschrijving</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="508"/>
+        <location filename="../VideoInfoView.qml" line="511"/>
         <source>Tags</source>
         <translation>Labels</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="518"/>
+        <location filename="../VideoInfoView.qml" line="521"/>
         <source>No tags</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source>No comments</source>
         <translation>Geen reacties</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source> comments</source>
         <translation> reacties</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="703"/>
+        <location filename="../VideoInfoView.qml" line="706"/>
         <source>No related videos</source>
         <translation>Geen gerelateerde videos</translation>
     </message>
@@ -1322,12 +1361,12 @@
         <translation type="obsolete">Kopiëren naar het klembord</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="86"/>
+        <location filename="../VideoListView.qml" line="82"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="108"/>
+        <location filename="../VideoListView.qml" line="104"/>
         <source>No videos found</source>
         <translation>Geen video&apos;s gevonden</translation>
     </message>
@@ -1349,50 +1388,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="40"/>
+        <location filename="../../../youtube.cpp" line="43"/>
         <source>Error obtaining access token</source>
         <translation>Fout bij het verkijgen van een toegangs certificaat</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="55"/>
+        <location filename="../../../youtube.cpp" line="54"/>
         <source>Authentication failed</source>
         <translation>Authenticatie is mislukt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="59"/>
+        <location filename="../../../youtube.cpp" line="58"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>U bent aangemeld bij YouTube als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="164"/>
-        <location filename="../../../youtube.cpp" line="270"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
         <translation>Error - Server antwoord is:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="214"/>
-        <location filename="../../../youtube.cpp" line="222"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Upload gestopt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="229"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload onderbroken. Probeert te hervatten ...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="233"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Upload mislukt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="239"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Upload is voltooid</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="437"/>
-        <location filename="../../../youtube.cpp" line="479"/>
+        <location filename="../../../youtube.cpp" line="397"/>
+        <location filename="../../../youtube.cpp" line="439"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fout: Kan geen video ophalen</translation>
     </message>
@@ -1598,34 +1637,24 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="156"/>
         <source>My Channel</source>
-        <translation>Mijn Kanaal</translation>
+        <translation type="obsolete">Mijn Kanaal</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="171"/>
         <source>Archive</source>
-        <translation>Archief</translation>
+        <translation type="obsolete">Archief</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Playlists</source>
-        <translation>Mijn Afspeellijst</translation>
+        <translation type="obsolete">Mijn Afspeellijst</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>My Subscriptions</source>
-        <translation>Mijn Abonnementen</translation>
+        <translation type="obsolete">Mijn Abonnementen</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
-        <source>Video Info</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Video Playback</source>
-        <translation>Video Afspelen</translation>
+        <translation type="obsolete">Video Afspelen</translation>
     </message>
     <message>
         <source>date</source>
@@ -1644,9 +1673,8 @@
         <translation type="obsolete">beoordelingen</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="256"/>
         <source>Search </source>
-        <translation>Zoeken </translation>
+        <translation type="obsolete">Zoeken </translation>
     </message>
 </context>
 <context>
