@@ -32,9 +32,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.6</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.7</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.7</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.7</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.8.0</source>
+        <translation type="unfinished">cuteTube-QML - 0.8.0</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -149,7 +153,7 @@
 <context>
     <name>BusyDialog</name>
     <message>
-        <location filename="../BusyDialog.qml" line="50"/>
+        <location filename="../BusyDialog.qml" line="47"/>
         <source>Loading...</source>
         <translation>Загрузка...</translation>
     </message>
@@ -314,6 +318,45 @@
         <translation>Архив</translation>
     </message>
 </context>
+<context>
+    <name>InboxDelegate</name>
+    <message>
+        <location filename="../InboxDelegate.qml" line="44"/>
+        <location filename="../InboxDelegate.qml" line="46"/>
+        <source>From </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="45"/>
+        <location filename="../InboxDelegate.qml" line="47"/>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source> on </source>
+        <translation type="unfinished"> от </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="95"/>
+        <source>By </source>
+        <translation type="unfinished">От </translation>
+    </message>
+    <message>
+        <location filename="../InboxDelegate.qml" line="145"/>
+        <source>Views</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>InboxDialog</name>
+    <message>
+        <location filename="../InboxDialog.qml" line="57"/>
+        <source>Inbox</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../InboxDialog.qml" line="69"/>
+        <source>No messages found</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MenuBar</name>
     <message>
@@ -341,37 +384,37 @@
         <translation type="obsolete">Загрузить видео</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="81"/>
+        <location filename="../MyAccountView.qml" line="98"/>
         <source>My Uploads</source>
         <translation>Загруженные</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="87"/>
+        <location filename="../MyAccountView.qml" line="104"/>
         <source>Uploads</source>
         <translation>Загруженные</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="105"/>
+        <location filename="../MyAccountView.qml" line="122"/>
         <source>My Favourites</source>
         <translation>Избранное</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="111"/>
+        <location filename="../MyAccountView.qml" line="128"/>
         <source>Favourites</source>
         <translation>Избранное</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="135"/>
+        <location filename="../MyAccountView.qml" line="152"/>
         <source>Playlists</source>
         <translation>Плейлисты</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="159"/>
+        <location filename="../MyAccountView.qml" line="176"/>
         <source>Subscriptions</source>
         <translation>Подписки</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="174"/>
+        <location filename="../MyAccountView.qml" line="191"/>
         <source>Signed in as:</source>
         <translation>Вы вошли как:</translation>
     </message>
@@ -425,12 +468,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="52"/>
+        <location filename="../NotificationArea.qml" line="55"/>
         <source>No active downloads</source>
         <translation>Нет активных загрузок</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="147"/>
+        <location filename="../NotificationArea.qml" line="151"/>
         <source>Downloads</source>
         <translation>Загрузки</translation>
     </message>
@@ -488,12 +531,12 @@
         <translation type="obsolete">Скопировать в буфер</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="69"/>
+        <location filename="../PlaylistVideosView.qml" line="71"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="92"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
@@ -552,7 +595,7 @@
         <translation type="obsolete">Просмотрам</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="178"/>
+        <location filename="../SearchBar.qml" line="183"/>
         <source>Order by:</source>
         <translation>Сортировать по:</translation>
     </message>
@@ -1178,12 +1221,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="129"/>
+        <location filename="../UserVideosView.qml" line="131"/>
         <source>You have subscribed to &apos;</source>
         <translation>Вы подписались на &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="133"/>
+        <location filename="../UserVideosView.qml" line="135"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Вы больше не подписаны на &apos;</translation>
     </message>
@@ -1212,27 +1255,27 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="153"/>
+        <location filename="../UserVideosView.qml" line="155"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="212"/>
+        <location filename="../UserVideosView.qml" line="214"/>
         <source>Subscribers</source>
         <translation>Подписчики</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="226"/>
+        <location filename="../UserVideosView.qml" line="228"/>
         <source>Videos</source>
         <translation>Видео</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Unsubscribe</source>
         <translation>Отписаться</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="249"/>
+        <location filename="../UserVideosView.qml" line="251"/>
         <source>Subscribe</source>
         <translation>Подписаться</translation>
     </message>
@@ -1245,17 +1288,17 @@
         <translation>Нет описания</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="92"/>
+        <location filename="../VideoInfoView.qml" line="93"/>
         <source>Your comment has been added</source>
         <translation>Ваш комментарий добавлен</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="95"/>
+        <location filename="../VideoInfoView.qml" line="96"/>
         <source>Your rating has been added</source>
         <translation>Ваша оценка добавлена</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="102"/>
+        <location filename="../VideoInfoView.qml" line="103"/>
         <source>Video shared on facebook</source>
         <translation>Видео опубликовано на Facebook</translation>
     </message>
@@ -1276,71 +1319,71 @@
         <translation type="obsolete">Опубликовать на Facebook</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="437"/>
-        <location filename="../VideoInfoView.qml" line="461"/>
-        <location filename="../VideoInfoView.qml" line="575"/>
+        <location filename="../VideoInfoView.qml" line="439"/>
+        <location filename="../VideoInfoView.qml" line="464"/>
+        <location filename="../VideoInfoView.qml" line="578"/>
         <source>You are not signed in to a YouTube account</source>
         <translation>Вы не вошли в аккаунт YouTube</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="244"/>
+        <location filename="../VideoInfoView.qml" line="245"/>
         <source>Info</source>
         <translation>Инфо</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="283"/>
+        <location filename="../VideoInfoView.qml" line="284"/>
         <source>Comments</source>
         <translation>Комментарий</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="322"/>
+        <location filename="../VideoInfoView.qml" line="323"/>
         <source>Related</source>
         <translation>Похожие</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="407"/>
-        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="408"/>
+        <location filename="../VideoInfoView.qml" line="411"/>
         <source>By </source>
         <translation>От </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="409"/>
-        <location filename="../VideoInfoView.qml" line="412"/>
+        <location filename="../VideoInfoView.qml" line="410"/>
+        <location filename="../VideoInfoView.qml" line="413"/>
         <source> on </source>
         <translation> от </translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="478"/>
+        <location filename="../VideoInfoView.qml" line="481"/>
         <source>Views</source>
         <translation>Просмотров</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="492"/>
+        <location filename="../VideoInfoView.qml" line="495"/>
         <source>Description</source>
         <translation>Описание</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="508"/>
+        <location filename="../VideoInfoView.qml" line="511"/>
         <source>Tags</source>
         <translation>Теги</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="518"/>
+        <location filename="../VideoInfoView.qml" line="521"/>
         <source>No tags</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source>No comments</source>
         <translation>Нет комментариев</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="587"/>
+        <location filename="../VideoInfoView.qml" line="590"/>
         <source> comments</source>
         <translation> комментариев</translation>
     </message>
     <message>
-        <location filename="../VideoInfoView.qml" line="703"/>
+        <location filename="../VideoInfoView.qml" line="706"/>
         <source>No related videos</source>
         <translation>Нет похожих видео</translation>
     </message>
@@ -1390,12 +1433,12 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="86"/>
+        <location filename="../VideoListView.qml" line="82"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="108"/>
+        <location filename="../VideoListView.qml" line="104"/>
         <source>No videos found</source>
         <translation>Видео не найдены</translation>
     </message>
@@ -1417,50 +1460,50 @@
 <context>
     <name>YouTube</name>
     <message>
-        <location filename="../../../youtube.cpp" line="40"/>
+        <location filename="../../../youtube.cpp" line="43"/>
         <source>Error obtaining access token</source>
         <translation>Ошибка при получении токена</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="55"/>
+        <location filename="../../../youtube.cpp" line="54"/>
         <source>Authentication failed</source>
         <translation>Ошибка аутентификации</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="59"/>
+        <location filename="../../../youtube.cpp" line="58"/>
         <source>You are signed in to YouTube as &apos;</source>
         <translation>Вы вошли на YouTube как &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="164"/>
-        <location filename="../../../youtube.cpp" line="270"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
         <translation>Ошибка - Ответ сервера:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="214"/>
-        <location filename="../../../youtube.cpp" line="222"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Загрузка отменена</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="229"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Загрузка прервана. Попытка возобновить...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="233"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Ошибка загрузки</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="239"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Загрузка завершена</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="437"/>
-        <location filename="../../../youtube.cpp" line="479"/>
+        <location filename="../../../youtube.cpp" line="397"/>
+        <location filename="../../../youtube.cpp" line="439"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Ошибка: Невозможно получить видео</translation>
     </message>
@@ -1670,34 +1713,28 @@
         <translation type="obsolete">Проигрыватель</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="156"/>
         <source>My Channel</source>
-        <translation>Мой Канал</translation>
+        <translation type="obsolete">Мой Канал</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="171"/>
         <source>Archive</source>
-        <translation>Архив</translation>
+        <translation type="obsolete">Архив</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Playlists</source>
-        <translation>Мой Плейлисты</translation>
+        <translation type="obsolete">Мой Плейлисты</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
         <source>My Subscriptions</source>
-        <translation>Мои Подписки</translation>
+        <translation type="obsolete">Мои Подписки</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="233"/>
         <source>Video Info</source>
-        <translation>Информация</translation>
+        <translation type="obsolete">Информация</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
         <source>Video Playback</source>
-        <translation>Качество Видео</translation>
+        <translation type="obsolete">Качество Видео</translation>
     </message>
     <message>
         <source>Downloads</source>
@@ -1720,9 +1757,8 @@
         <translation type="obsolete">рейтингу</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="256"/>
         <source>Search </source>
-        <translation>Поиск </translation>
+        <translation type="obsolete">Поиск </translation>
     </message>
 </context>
 <context>
