@@ -81,7 +81,7 @@ void YouTube::uploadVideo(const QString &filename, const QString &title, const Q
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
                    "<media:group>\n" \
                    "<media:title>" + title.toAscii() + "</media:title>\n" \
-                   "<media:description>\n" + description.toAscii() + "\n\n" + "Uploaded via cuteTube on Symbian^3\n</media:description>\n" \
+                   "<media:description>\n" + description.toAscii() + "\n\n" + "Uploaded via cuteTube on the Nokia N900\n</media:description>\n" \
                    "<media:category scheme=\"http://gdata.youtube.com/schemas/2007/categories.cat\">\n" + category.toAscii() + "\n</media:category>\n" \
                    "<media:keywords>" + tags.toAscii() + "</media:keywords>\n" \
                    "</media:group>\n" \
